@@ -1,22 +1,20 @@
-context("test_byars")
-
 #test calculations
 test_that("byars_lower calculate correctly",{
 
   expect_equal(data.frame(lowercl = byars_lower(c(65,1045,1))),
-               data.frame(slice(test_BW,1:3)[3]),check.attributes=FALSE, check.names=FALSE, info="test default")
+               data.frame(slice(test_BW,1:3)[3]),ignore_attr=TRUE, info="test default")
 
   expect_equal(data.frame(lowercl = byars_lower(c(65,1045,10),confidence=99.8)),
-               data.frame(slice(test_BW,4:6)[3]),check.attributes=FALSE, check.names=FALSE, info="test default")
+               data.frame(slice(test_BW,4:6)[3]),ignore_attr=TRUE, info="test default")
 
   expect_equal(data.frame(lowercl = byars_upper(c(65,1045,1))),
-               data.frame(slice(test_BW,1:3)[4]),check.attributes=FALSE, check.names=FALSE, info="test default")
+               data.frame(slice(test_BW,1:3)[4]),ignore_attr=TRUE, info="test default")
 
   expect_equal(data.frame(lowercl = byars_upper(c(65,1045,10),confidence=0.998)),
-               data.frame(slice(test_BW,4:6)[4]),check.attributes=FALSE, check.names=FALSE, info="test default")
+               data.frame(slice(test_BW,4:6)[4]),ignore_attr=TRUE, info="test default")
 
   expect_equal(data.frame(lowercl = byars_upper(c(65,1045,10),confidence=99.8)),
-               data.frame(slice(test_BW,4:6)[4]),check.attributes=FALSE, check.names=FALSE, info="test default")
+               data.frame(slice(test_BW,4:6)[4]),ignore_attr=TRUE, info="test default")
 
 })
 
